# `notebooks/`

This directory contains jupyter notebooks and python scripts used to make plots
for our papers. For example, `hazma_paper/` contains all the plots linked to
under the figures in our code release paper.
